import { Request as NodeFetchRequest } from 'node-fetch';
import FormData from 'form-data';
import { NFCResponse } from './classes/response.js';
import { MemoryCache } from './classes/caching/memory_cache.js';
import type { CacheStrategy, FetchInit, FetchResource, INodeFetchCacheCache } from './types.js';
import { calculateCacheKey } from './helpers/cache_keys.js';
type CacheKeyCalculator = typeof calculateCacheKey;
type NFCCustomizations = {
    cache: INodeFetchCacheCache;
    calculateCacheKey: CacheKeyCalculator;
    shouldCacheResponse: CacheStrategy;
};
type NFCOptions = Partial<NFCCustomizations>;
declare function create(creationOptions: NFCOptions): {
    (resource: FetchResource, init?: FetchInit, perRequestOptions?: NFCOptions): Promise<NFCResponse>;
    create: typeof create;
    options: {
        cache: INodeFetchCacheCache | MemoryCache;
        shouldCacheResponse: CacheStrategy;
        calculateCacheKey: typeof calculateCacheKey;
    };
};
declare const defaultFetch: {
    (resource: FetchResource, init?: FetchInit, perRequestOptions?: NFCOptions): Promise<NFCResponse>;
    create: typeof create;
    options: {
        cache: INodeFetchCacheCache | MemoryCache;
        shouldCacheResponse: CacheStrategy;
        calculateCacheKey: typeof calculateCacheKey;
    };
};
declare const cacheStrategies: {
    cacheOkayOnly: CacheStrategy;
    cacheNon5xxOnly: CacheStrategy;
};
export default defaultFetch;
export { MemoryCache } from './classes/caching/memory_cache.js';
export { FileSystemCache } from './classes/caching/file_system_cache.js';
export { CACHE_VERSION } from './helpers/cache_keys.js';
export type { NFCResponse } from './classes/response.js';
export type { NFCResponseMetadata } from './types.js';
export { defaultFetch as NodeFetchCache, cacheStrategies, calculateCacheKey as getCacheKey, calculateCacheKey, FormData, NodeFetchRequest, type NFCOptions, type CacheKeyCalculator, type INodeFetchCacheCache, type FetchResource, type FetchInit, };
